==> revive-adserver-5.1.0.zip: revive-adserver-5.1.0/lib/max/language/pl/invocation.lang.php <==
<?php

/*
  +---------------------------------------------------------------------------+
  | Revive Adserver                                                           |
  | http://www.revive-adserver.com                                            |
  |                                                                           |
  | Copyright: See the COPYRIGHT.txt file.                                    |
  | License: GPLv2 or later, see the LICENSE.txt file.                        |
  +---------------------------------------------------------------------------+
 */

// Other
$GLOBALS['strCopyToClipboard'] = "Kopiuj do schowka";
$GLOBALS['strCopy'] = "kopiuj";
$GLOBALS['strChooseTypeOfInvocation'] = "Wybierz typ kodu wywołującego";
$GLOBALS['strChooseTypeOfBannerInvocation'] = "Wybierz typ kodu wywołującego baner";

// Measures
$GLOBALS['strAbbrPixels'] = "piks";
$GLOBALS['strAbbrSeconds'] = "sek";

// Common Invocation Parameters
$GLOBALS['strInvocationWhat'] = "Wybór banera";
$GLOBALS['strInvocationCampaignID'] = "Kampania";
$GLOBALS['strInvocationTarget'] = "Ramka docelowa";
$GLOBALS['strInvocationSource'] = "Źródło";
$GLOBALS['strInvocationWithText'] = "Pokaż tekst pod banerem";
$GLOBALS['strInvocationDontShowAgain'] = "Nie pokazuj banera drugi raz na tej samej stronie";
$GLOBALS['strInvocationDontShowAgainCampaign'] = "Nie pokazuj banera z tej samej kampanii po raz drugi na tej samej stronie";
$GLOBALS['strInvocationTemplate'] = "Zapisz ten baner w zmiennej, aby mógł być wkorzystany w szablonie";
$GLOBALS['strInvocationBannerID'] = "ID banera";
$GLOBALS['strInvocationComments'] = "Dołącz komentarze";

// Iframe
$GLOBALS['strIFrameRefreshAfter'] = "Odśwież po";
$GLOBALS['strIframeResizeToBanner'] = "Przeskaluj iframe do rozmiarów banera";
$GLOBALS['strIframeMakeTransparent'] = "Zrób przezroczystą iframe";
$GLOBALS['strIframeIncludeNetscape4'] = "Dodaj warstwę kompatybilną z Netscape 4";
$GLOBALS['strIframeGoogleClickTracking'] = "Dołącz kod do śledzenia kliknięć Google AdSense";

// PopUp
$GLOBALS['strPopUpStyle'] = "Typ Pop-up";
$GLOBALS['strPopUpCreateInstance'] = "Kiedy pop-up ma być wyświetlony";
$GLOBALS['strPopUpImmediately'] = "Natychmiast";
$GLOBALS['strPopUpOnClose'] = "Kiedy strona jest zamykana";
$GLOBALS['strPopUpAfterSec'] = "Po";
$GLOBALS['strAutoCloseAfter'] = "Automatycznie zamknij po";
$GLOBALS['strPopUpTop'] = "Początkowa pozycja (góra)";
$GLOBALS['strPopUpLeft'] = "Początkowa pozycja (lewa)";

// XML-RPC
$GLOBALS['strXmlRpcLanguage'] = "Język Hosta";

// Support for cachebusting code
$GLOBALS['strCacheBuster'] = "Wstaw kod Cache-Busting";

// IMG invocation selected for tracker with appended code
$GLOBALS['strImgWithAppendWarning'] = "Do trackera załączony jest kod, który funkcjonuje <strong>wyłącznie</strong> ze znacznikami JavaScript";

// Local Invocation

==> revive-adserver-5.4.1.zip: revive-adserver-5.4.1/lib/max/language/pl/invocation.lang.php <==
<?php

/*
  +---------------------------------------------------------------------------+
  | Revive Adserver                                                           |
  | http://www.revive-adserver.com                                            |
  |                                                                           |
  | Copyright: See the COPYRIGHT.txt file.                                    |
  | License: GPLv2 or later, see the LICENSE.txt file.                        |
  +---------------------------------------------------------------------------+
 */

// Other
$GLOBALS['strCopyToClipboard'] = "Kopiuj do schowka";
$GLOBALS['strCopy'] = "kopiuj";
$GLOBALS['strChooseTypeOfInvocation'] = "Wybierz typ kodu wywołującego";
$GLOBALS['strChooseTypeOfBannerInvocation'] = "Wybierz typ kodu wywołującego baner";

// Measures
$GLOBALS['strAbbrPixels'] = "piks";
$GLOBALS['strAbbrSeconds'] = "sek";

// Common Invocation Parameters
$GLOBALS['strInvocationWhat'] = "Wybór banera";
$GLOBALS['strInvocationCampaignID'] = "Kampania";
$GLOBALS['strInvocationTarget'] = "Ramka docelowa";
$GLOBALS['strInvocationSource'] = "Źródło";
$GLOBALS['strInvocationWithText'] = "Pokaż tekst pod banerem";
$GLOBALS['strInvocationDontShowAgain'] = "Nie pokazuj banera drugi raz na tej samej stronie";
$GLOBALS['strInvocationDontShowAgainCampaign'] = "Nie pokazuj banera z tej samej kampanii po raz drugi na tej samej stronie";
$GLOBALS['strInvocationTemplate'] = "Zapisz ten baner w zmiennej, aby mógł być wkorzystany w szablonie";
$GLOBALS['strInvocationBannerID'] = "ID banera";
$GLOBALS['strInvocationComments'] = "Dołącz komentarze";

// Iframe
$GLOBALS['strIFrameRefreshAfter'] = "Odśwież po";
$GLOBALS['strIframeMakeTransparent'] = "Zrób przezroczystą iframe";

// PopUp
$GLOBALS['strPopUpStyle'] = "Typ Pop-up";
$GLOBALS['strPopUpCreateInstance'] = "Kiedy pop-up ma być wyświetlony";
$GLOBALS['strPopUpImmediately'] = "Natychmiast";
$GLOBALS['strPopUpOnClose'] = "Kiedy strona jest zamykana";
$GLOBALS['strPopUpAfterSec'] = "Po";
$GLOBALS['strAutoCloseAfter'] = "Automatycznie zamknij po";
$GLOBALS['strPopUpTop'] = "Początkowa pozycja (góra)";
$GLOBALS['strPopUpLeft'] = "Początkowa pozycja (lewa)";

// Support for cachebusting code
$GLOBALS['strCacheBuster'] = "Wstaw kod Cache-Busting";

// IMG invocation selected for tracker with appended code
$GLOBALS['strWarning'] = "Uwaga";
$GLOBALS['strImgWithAppendWarning'] = "Do trackera załączony jest kod, który funkcjonuje <strong>wyłącznie</strong> ze znacznikami JavaScript";
